syntax = "proto3";

option optimize_for = LITE_RUNTIME;
option go_package = "github.com/formicidae-tracker/hermes";

package fort.hermes;

message Tag {
	uint32 ID    = 1;
	double x     = 2;
	double y     = 3;
	double theta = 4;
};
