syntax = "proto3";

option optimize_for = LITE_RUNTIME;
option go_package = "github.com/formicidae-tracker/hermes";

import "google/protobuf/timestamp.proto";
import "google/protobuf/any.proto";
import "Tag.proto";

package fort.hermes;


message FrameReadout {

	enum Error {
		NO_ERROR = 0;
		PROCESS_OVERFLOW   = 1;
		PROCESS_TIMEOUT    = 2;
		ILLUMINATION_ERROR = 3;

}
	int64                     timestamp     = 1;
	int64                     frameID       = 2;
	repeated Tag              tags          = 3;
	google.protobuf.Timestamp time          = 4;
	Error                     error         = 5;
	string                    producer_uuid = 6;
	int32                     quads         = 7;
	int32                     width         = 8;
	int32                     height        = 9;
	google.protobuf.Timestamp cuestart      = 10;
	google.protobuf.Timestamp cueend        = 11;

	repeated google.protobuf.Any extensions = 12;
};
