# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FrameReadout.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from . import Tag_pb2 as Tag__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='FrameReadout.proto',
  package='fort.hermes',
  syntax='proto3',
  serialized_options=b'H\003Z$github.com/formicidae-tracker/hermes',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x12\x46rameReadout.proto\x12\x0b\x66ort.hermes\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\tTag.proto\"\xcf\x03\n\x0c\x46rameReadout\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x0f\n\x07\x66rameID\x18\x02 \x01(\x03\x12\x1e\n\x04tags\x18\x03 \x03(\x0b\x32\x10.fort.hermes.Tag\x12(\n\x04time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\x05\x65rror\x18\x05 \x01(\x0e\x32\x1f.fort.hermes.FrameReadout.Error\x12\x15\n\rproducer_uuid\x18\x06 \x01(\t\x12\r\n\x05quads\x18\x07 \x01(\x05\x12\r\n\x05width\x18\x08 \x01(\x05\x12\x0e\n\x06height\x18\t \x01(\x05\x12,\n\x08\x63uestart\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x63ueend\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\nextensions\x18\x0c \x03(\x0b\x32\x14.google.protobuf.Any\"X\n\x05\x45rror\x12\x0c\n\x08NO_ERROR\x10\x00\x12\x14\n\x10PROCESS_OVERFLOW\x10\x01\x12\x13\n\x0fPROCESS_TIMEOUT\x10\x02\x12\x16\n\x12ILLUMINATION_ERROR\x10\x03\x42(H\x03Z$github.com/formicidae-tracker/hermesb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,Tag__pb2.DESCRIPTOR,])



_FRAMEREADOUT_ERROR = _descriptor.EnumDescriptor(
  name='Error',
  full_name='fort.hermes.FrameReadout.Error',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NO_ERROR', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROCESS_OVERFLOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROCESS_TIMEOUT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ILLUMINATION_ERROR', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=482,
  serialized_end=570,
)
_sym_db.RegisterEnumDescriptor(_FRAMEREADOUT_ERROR)


_FRAMEREADOUT = _descriptor.Descriptor(
  name='FrameReadout',
  full_name='fort.hermes.FrameReadout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='fort.hermes.FrameReadout.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frameID', full_name='fort.hermes.FrameReadout.frameID', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tags', full_name='fort.hermes.FrameReadout.tags', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='fort.hermes.FrameReadout.time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='fort.hermes.FrameReadout.error', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='producer_uuid', full_name='fort.hermes.FrameReadout.producer_uuid', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quads', full_name='fort.hermes.FrameReadout.quads', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='fort.hermes.FrameReadout.width', index=7,
      number=8, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='fort.hermes.FrameReadout.height', index=8,
      number=9, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cuestart', full_name='fort.hermes.FrameReadout.cuestart', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cueend', full_name='fort.hermes.FrameReadout.cueend', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extensions', full_name='fort.hermes.FrameReadout.extensions', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FRAMEREADOUT_ERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=107,
  serialized_end=570,
)

_FRAMEREADOUT.fields_by_name['tags'].message_type = Tag__pb2._TAG
_FRAMEREADOUT.fields_by_name['time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FRAMEREADOUT.fields_by_name['error'].enum_type = _FRAMEREADOUT_ERROR
_FRAMEREADOUT.fields_by_name['cuestart'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FRAMEREADOUT.fields_by_name['cueend'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_FRAMEREADOUT.fields_by_name['extensions'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_FRAMEREADOUT_ERROR.containing_type = _FRAMEREADOUT
DESCRIPTOR.message_types_by_name['FrameReadout'] = _FRAMEREADOUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FrameReadout = _reflection.GeneratedProtocolMessageType('FrameReadout', (_message.Message,), {
  'DESCRIPTOR' : _FRAMEREADOUT,
  '__module__' : 'FrameReadout_pb2'
  # @@protoc_insertion_point(class_scope:fort.hermes.FrameReadout)
  })
_sym_db.RegisterMessage(FrameReadout)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
