# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: Header.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import FrameReadout_pb2 as FrameReadout__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='Header.proto',
  package='fort.hermes',
  syntax='proto3',
  serialized_options=b'H\003Z$github.com/formicidae-tracker/hermes',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0cHeader.proto\x12\x0b\x66ort.hermes\x1a\x12\x46rameReadout.proto\")\n\x07Version\x12\x0e\n\x06vmajor\x18\x01 \x01(\r\x12\x0e\n\x06vminor\x18\x02 \x01(\r\"\xbf\x01\n\x06Header\x12%\n\x07version\x18\x01 \x01(\x0b\x32\x14.fort.hermes.Version\x12&\n\x04type\x18\x02 \x01(\x0e\x32\x18.fort.hermes.Header.Type\x12\x10\n\x08previous\x18\x03 \x01(\t\x12\r\n\x05width\x18\x04 \x01(\x05\x12\x0e\n\x06height\x18\x05 \x01(\x05\x12\x16\n\x0e\x65xtensionTypes\x18\x06 \x03(\t\"\x1d\n\x04Type\x12\x0b\n\x07Network\x10\x00\x12\x08\n\x04\x46ile\x10\x01\"\x16\n\x06\x46ooter\x12\x0c\n\x04next\x18\x01 \x01(\t\"[\n\x08\x46ileLine\x12*\n\x07readout\x18\x01 \x01(\x0b\x32\x19.fort.hermes.FrameReadout\x12#\n\x06\x66ooter\x18\x02 \x01(\x0b\x32\x13.fort.hermes.FooterB(H\x03Z$github.com/formicidae-tracker/hermesb\x06proto3'
  ,
  dependencies=[FrameReadout__pb2.DESCRIPTOR,])



_HEADER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='fort.hermes.Header.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='Network', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='File', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=255,
  serialized_end=284,
)
_sym_db.RegisterEnumDescriptor(_HEADER_TYPE)


_VERSION = _descriptor.Descriptor(
  name='Version',
  full_name='fort.hermes.Version',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vmajor', full_name='fort.hermes.Version.vmajor', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vminor', full_name='fort.hermes.Version.vminor', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=90,
)


_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='fort.hermes.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='fort.hermes.Header.version', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='fort.hermes.Header.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='previous', full_name='fort.hermes.Header.previous', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='fort.hermes.Header.width', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='fort.hermes.Header.height', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extensionTypes', full_name='fort.hermes.Header.extensionTypes', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HEADER_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=93,
  serialized_end=284,
)


_FOOTER = _descriptor.Descriptor(
  name='Footer',
  full_name='fort.hermes.Footer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='next', full_name='fort.hermes.Footer.next', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=286,
  serialized_end=308,
)


_FILELINE = _descriptor.Descriptor(
  name='FileLine',
  full_name='fort.hermes.FileLine',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='readout', full_name='fort.hermes.FileLine.readout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='footer', full_name='fort.hermes.FileLine.footer', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=401,
)

_HEADER.fields_by_name['version'].message_type = _VERSION
_HEADER.fields_by_name['type'].enum_type = _HEADER_TYPE
_HEADER_TYPE.containing_type = _HEADER
_FILELINE.fields_by_name['readout'].message_type = FrameReadout__pb2._FRAMEREADOUT
_FILELINE.fields_by_name['footer'].message_type = _FOOTER
DESCRIPTOR.message_types_by_name['Version'] = _VERSION
DESCRIPTOR.message_types_by_name['Header'] = _HEADER
DESCRIPTOR.message_types_by_name['Footer'] = _FOOTER
DESCRIPTOR.message_types_by_name['FileLine'] = _FILELINE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Version = _reflection.GeneratedProtocolMessageType('Version', (_message.Message,), {
  'DESCRIPTOR' : _VERSION,
  '__module__' : 'Header_pb2'
  # @@protoc_insertion_point(class_scope:fort.hermes.Version)
  })
_sym_db.RegisterMessage(Version)

Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), {
  'DESCRIPTOR' : _HEADER,
  '__module__' : 'Header_pb2'
  # @@protoc_insertion_point(class_scope:fort.hermes.Header)
  })
_sym_db.RegisterMessage(Header)

Footer = _reflection.GeneratedProtocolMessageType('Footer', (_message.Message,), {
  'DESCRIPTOR' : _FOOTER,
  '__module__' : 'Header_pb2'
  # @@protoc_insertion_point(class_scope:fort.hermes.Footer)
  })
_sym_db.RegisterMessage(Footer)

FileLine = _reflection.GeneratedProtocolMessageType('FileLine', (_message.Message,), {
  'DESCRIPTOR' : _FILELINE,
  '__module__' : 'Header_pb2'
  # @@protoc_insertion_point(class_scope:fort.hermes.FileLine)
  })
_sym_db.RegisterMessage(FileLine)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
